###Loading the necessary libraries 
library(mgcv)
library(gratia)
library(forecast)

###Loading and preparing the data (First it is needed to import the file "database.xlsx")
data <- database
data$Management_unit <- as.factor(data$Management_unit)
datanoNA <- na.exclude(data)


###Model with saltmarsh production (NDVI) as response variable
gam_saltmarsh <- gam(Saltmarsh_NDVI~s(Saltmarsh_rainfall, k=5, bs="tp") + s(Saltmarsh_phenology, k=5,bs="tp") +
              s(Horse_density, k=5,bs="tp") +
              s(Cattle_density, k=5,bs="tp") +
              s(Fallow_deer_density, k=5,bs="tp") +
              s(Red_deer_density, k=5,bs="tp") +
              s(Management_unit, k=5, bs="re") + ti(Saltmarsh_rainfall,Saltmarsh_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
            family = gaussian, data = datanoNA, select = T)

#Summary (Table 3 in the manuscript)
summary(gam_saltmarsh)

#Diagnostic plots (Figure S1 in the manuscript)
par(mfrow = c(2, 2))
gam.check(gam_saltmarsh, rep = 500)

#Predictor effects (Only the contour plots of the residual interaction between rainfall/phenology are present in the Figure S3 in the manuscript)
par(mfrow = c(1, 1))
draw(gam_saltmarsh, scales = "fixed")

#Predictor effects -Single plot for each predictor using the plot function. (Figure 3 in the manuscript)
plot(gam_saltmarsh, scale = -1, seWithMean = TRUE, shade = T, pages=9, ylim = c(-0.3,0.2), shade.col = "lightblue3", xlab = '',ylab = '')


#Contour plots of rainfall-phenology interactions (Figure 4 in the manuscript)
vis.gam(gam_saltmarsh, view = c("Saltmarsh_phenology","Saltmarsh_rainfall"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.1, xlim=c(0,365), ylim=c(0,800)) 

#Contour plot of model predictions (Interactions between domestic ungulate densities and rainfall and phenology. Figure 5 in the manuscript)
vis.gam(gam_saltmarsh, view = c("Saltmarsh_rainfall","Horse_density"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.7, xlim=c(min(datanoNA$Saltmarsh_rainfall),max(datanoNA$Saltmarsh_rainfall)), ylim=c(min(datanoNA$Horse_density),max(datanoNA$Horse_density))) 

vis.gam(gam_saltmarsh, view = c("Saltmarsh_phenology","Horse_density"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.7, xlim=c(min(datanoNA$Saltmarsh_phenology),max(datanoNA$Saltmarsh_phenology)), ylim=c(min(datanoNA$Horse_density),max(datanoNA$Horse_density))) 

#autocorrelation plot (Figure S2 in the manuscript)
Acf(residuals(gam_saltmarsh), ylim=c(-1,1))

###Model with bullrush marsh production (NDVI) as response variable
gam_bullrush_marsh <- gam(Bullrush_marsh_NDVI~s(Bullrush_marsh_rainfall, k=5, bs="tp") + s(Bullrush_marsh_phenology, k=5,bs="tp") +
                       s(Horse_density, k=5,bs="tp") +
                       s(Cattle_density, k=5,bs="tp") +
                       s(Fallow_deer_density, k=5,bs="tp") +
                       s(Red_deer_density, k=5,bs="tp") +
                       s(Management_unit, k=5, bs="re") + ti(Bullrush_marsh_rainfall,Bullrush_marsh_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
                     family = gaussian, data = datanoNA, select = T)

#Summary (Table 3 in the manuscript)
summary(gam_bullrush_marsh)

#Diagnostic plots (Figure S1 in the manuscript)
par(mfrow = c(2, 2))
gam.check(gam_bullrush_marsh, rep = 500)

#Predictor effects (Only the contour plots of the residual interaction between rainfall/phenology are present in the Figure S3 in the manuscript)
par(mfrow = c(1, 1))
draw(gam_bullrush_marsh, scales = "fixed")

#Predictor effects -Single plot for each predictor using the plot function. (Figure 3 in the manuscript)
plot(gam_bullrush_marsh, scale = -1, seWithMean = TRUE, shade = T, pages=9, ylim = c(-0.3,0.2), shade.col = "lightblue3", xlab = '',ylab = '')


#Contour plots of rainfall-phenology interactions (Figure 4 in the manuscript)
vis.gam(gam_bullrush_marsh, view = c("Bullrush_marsh_phenology","Bullrush_marsh_rainfall"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.1, xlim=c(0,365), ylim=c(0,800)) 

#Contour plot of model predictions (Interactions between domestic ungulate densities and rainfall and phenology. Figure 5 in the manuscript)
vis.gam(gam_bullrush_marsh, view = c("Bullrush_marsh_rainfall","Cattle_density"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.7, xlim=c(min(datanoNA$Bullrush_marsh_rainfall),max(datanoNA$Bullrush_marsh_rainfall)), ylim=c(min(datanoNA$Cattle_density),max(datanoNA$Cattle_density))) 

vis.gam(gam_bullrush_marsh, view = c("Bullrush_marsh_phenology","Cattle_density"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.7, xlim=c(min(datanoNA$Bullrush_marsh_phenology),max(datanoNA$Bullrush_marsh_phenology)), ylim=c(min(datanoNA$Cattle_density),max(datanoNA$Cattle_density))) 

#autocorrelation plot (Figure S2 in the manuscript)
Acf(residuals(gam_bullrush_marsh), ylim=c(-1,1))

###Model with shrubland production (NDVI) as response variable
gam_shrubland <- gam(Shrubland_NDVI~s(Shrubland_rainfall, k=5, bs="tp") + s(Shrubland_phenology, k=5,bs="tp") +
                       s(Horse_density, k=5,bs="tp") +
                       s(Cattle_density, k=5,bs="tp") +
                       s(Fallow_deer_density, k=5,bs="tp") +
                       s(Red_deer_density, k=5,bs="tp") +
                       s(Management_unit, k=5, bs="re") + ti(Shrubland_rainfall,Shrubland_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
                     family = gaussian, data = datanoNA, select = T)

#Summary (Table 3 in the manuscript)
summary(gam_shrubland)

#Diagnostic plots (Figure S1 in the manuscript)
par(mfrow = c(2, 2))
gam.check(gam_shrubland, rep = 500)

#Predictor effects (Only the contour plots of the residual interaction between rainfall/phenology are present in the Figure S3 in the manuscript)
par(mfrow = c(1, 1))
draw(gam_shrubland, scales = "fixed")

#Predictor effects -Single plot for each predictor using the plot function. (Figure 3 in the manuscript)
plot(gam_shrubland, scale = -1, seWithMean = TRUE, shade = T, pages=9, ylim = c(-0.3,0.2), shade.col = "lightblue3", xlab = '',ylab = '')


#Contour plots of rainfall-phenology interactions (Figure 4 in the manuscript)
vis.gam(gam_shrubland, view = c("Shrubland_phenology","Shrubland_rainfall"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.1, xlim=c(0,365), ylim=c(0,800)) 

#autocorrelation plot (Figure S2 in the manuscript)
Acf(residuals(gam_shrubland), ylim=c(-1,1))

###Model with grassland production (NDVI) as response variable
gam_grassland <- gam(Grassland_NDVI~s(Grassland_rainfall, k=5, bs="tp") + s(Grassland_phenology, k=5,bs="tp") +
                       s(Horse_density, k=5,bs="tp") +
                       s(Cattle_density, k=5,bs="tp") +
                       s(Fallow_deer_density, k=5,bs="tp") +
                       s(Red_deer_density, k=5,bs="tp") +
                       s(Management_unit, k=5, bs="re") + ti(Grassland_rainfall,Grassland_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
                     family = gaussian, data = datanoNA, select = T)

#Summary (Table 3 in the manuscript)
summary(gam_grassland)

#Diagnostic plots (Figure S1 in the manuscript)
par(mfrow = c(2, 2))
gam.check(gam_grassland, rep = 500)

#Predictor effects (Only the contour plots of the residual interaction between rainfall/phenology are present in the Figure S3 in the manuscript)
par(mfrow = c(1, 1))
draw(gam_grassland, scales = "fixed")

#Predictor effects -Single plot for each predictor using the plot function. (Figure 3 in the manuscript)
plot(gam_grassland, scale = -1, seWithMean = TRUE, shade = T, pages=9, ylim = c(-0.3,0.2), shade.col = "lightblue3", xlab = '',ylab = '')

#Contour plots of rainfall-phenology interactions (Figure 4 in the manuscript)
vis.gam(gam_grassland, view = c("Grassland_phenology","Grassland_rainfall"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.1, xlim=c(0,365), ylim=c(0,800)) 


#Running the Model with grassland production (NDVI) as response variable but merging cattle and horse
#densities in "livestock density" to create the prediction plots for grassland.
gam_grassland_livestock <- gam(Grassland_NDVI~s(Grassland_rainfall, k=5, bs="tp") + s(Grassland_phenology, k=5,bs="tp") +
                       s(Livestock_density, k=5,bs="tp") +
                       s(Fallow_deer_density, k=5,bs="tp") +
                       s(Red_deer_density, k=5,bs="tp") +
                       s(Management_unit, k=5, bs="re") + ti(Grassland_rainfall,Grassland_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
                     family = gaussian, data = datanoNA, select = T)

#Plot to visually check the correlation between the results of the model with grassland/separate cattle and horse densities
#and the model with grassland/livestock (merging cattle and horse densities)
gam_grassland$fitted.values

gam_grassland_livestock$fitted.values

cor(gam_grassland$fitted.values,gam_grassland_livestock$fitted.values)

plot(gam_grassland$fitted.values,gam_grassland_livestock$fitted.values,xlab = "model with livestock", ylab = "model with cattle and horse")


#Contour plot of model predictions (Interactions between domestic ungulate densities (livestock) and rainfall and phenology. Figure 5 in the manuscript)
vis.gam(gam_grassland_livestock, view = c("Grassland_rainfall","Livestock_density"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.7, xlim=c(min(datanoNA$Grassland_rainfall),max(datanoNA$Grassland_rainfall)), ylim=c(min(datanoNA$Livestock_density),max(datanoNA$Livestock_density))) 

vis.gam(gam_grassland_livestock, view = c("Grassland_phenology","Livestock_density"), color = "topo",type = "link", plot.type = "contour"
        ,too.far = 0.7, xlim=c(min(datanoNA$Grassland_phenology),max(datanoNA$Grassland_phenology)), ylim=c(min(datanoNA$Livestock_density),max(datanoNA$Livestock_density))) 

#autocorrelation plot (Figure S2 in the manuscript)
Acf(residuals(gam_grassland), ylim=c(-1,1))

####Alternative gam models -using the beginning-of-the-season values of ungulate census- predicting plant production.

###Loading and preparing the data (First it is needed to import the file "database1.xlsx")
data <- database1
data$Management_unit <- as.factor(data$Management_unit)
datanoNA <- na.exclude(data)


###Model with saltmarsh production (NDVI) as response variable
gam_saltmarsh <- gam(Saltmarsh_NDVI~s(Saltmarsh_rainfall, k=5, bs="tp") + s(Saltmarsh_phenology, k=5,bs="tp") +
                             s(Horse_density, k=5,bs="tp") +
                             s(Cattle_density, k=5,bs="tp") +
                             s(Fallow_deer_density, k=5,bs="tp") +
                             s(Red_deer_density, k=5,bs="tp") +
                             s(Management_unit, k=5, bs="re") + ti(Saltmarsh_rainfall,Saltmarsh_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
                     family = gaussian, data = datanoNA, select = T)

#Summary (Table 3 in the manuscript)
summary(gam_saltmarsh)

#Diagnostic plots (Figure S1 in the manuscript)
par(mfrow = c(2, 2))
gam.check(gam_saltmarsh, rep = 500)

###Model with bullrush marsh production (NDVI) as response variable
gam_bullrush_marsh <- gam(Bullrush_marsh_NDVI~s(Bullrush_marsh_rainfall, k=5, bs="tp") + s(Bullrush_marsh_phenology, k=5,bs="tp") +
                                  s(Horse_density, k=5,bs="tp") +
                                  s(Cattle_density, k=5,bs="tp") +
                                  s(Fallow_deer_density, k=5,bs="tp") +
                                  s(Red_deer_density, k=5,bs="tp") +
                                  s(Management_unit, k=5, bs="re") + ti(Bullrush_marsh_rainfall,Bullrush_marsh_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
                          family = gaussian, data = datanoNA, select = T)

#Summary (Table 3 in the manuscript)
summary(gam_bullrush_marsh)

#Diagnostic plots (Figure S1 in the manuscript)
par(mfrow = c(2, 2))
gam.check(gam_bullrush_marsh, rep = 500)

###Model with shrubland production (NDVI) as response variable
gam_shrubland <- gam(Shrubland_NDVI~s(Shrubland_rainfall, k=5, bs="tp") + s(Shrubland_phenology, k=5,bs="tp") +
                             s(Horse_density, k=5,bs="tp") +
                             s(Cattle_density, k=5,bs="tp") +
                             s(Fallow_deer_density, k=5,bs="tp") +
                             s(Red_deer_density, k=5,bs="tp") +
                             s(Management_unit, k=5, bs="re") + ti(Shrubland_rainfall,Shrubland_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
                     family = gaussian, data = datanoNA, select = T)

#Summary (Table 3 in the manuscript)
summary(gam_shrubland)

#Diagnostic plots (Figure S1 in the manuscript)
par(mfrow = c(2, 2))
gam.check(gam_shrubland, rep = 500)

###Model with grassland production (NDVI) as response variable
gam_grassland <- gam(Grassland_NDVI~s(Grassland_rainfall, k=5, bs="tp") + s(Grassland_phenology, k=5,bs="tp") +
                             s(Horse_density, k=5,bs="tp") +
                             s(Cattle_density, k=5,bs="tp") +
                             s(Fallow_deer_density, k=5,bs="tp") +
                             s(Red_deer_density, k=5,bs="tp") +
                             s(Management_unit, k=5, bs="re") + ti(Grassland_rainfall,Grassland_phenology)+ s(Year,k = 14,bs="cc"),method = "REML",
                     family = gaussian, data = datanoNA, select = T)

#Summary (Table 3 in the manuscript)
summary(gam_grassland)

#Diagnostic plots (Figure S1 in the manuscript)
par(mfrow = c(2, 2))
gam.check(gam_grassland, rep = 500)